.. AUTO-GENERATED FILE -- DO NOT EDIT!

:mod:`skimage`
==============
.. automodule:: skimage

.. currentmodule:: skimage
.. autosummary::

   skimage.dtype_limits
   skimage.ensure_python_version
   skimage.img_as_bool
   skimage.img_as_float
   skimage.img_as_float32
   skimage.img_as_float64
   skimage.img_as_int
   skimage.img_as_ubyte
   skimage.img_as_uint
   skimage.lookfor


    skimage.data
    skimage.util

dtype_limits
------------

.. autofunction:: skimage.dtype_limits


.. include:: skimage.dtype_limits.examples

ensure_python_version
---------------------

.. autofunction:: skimage.ensure_python_version


.. include:: skimage.ensure_python_version.examples

img_as_bool
-----------

.. autofunction:: skimage.img_as_bool


.. include:: skimage.img_as_bool.examples

img_as_float
------------

.. autofunction:: skimage.img_as_float


.. include:: skimage.img_as_float.examples

img_as_float32
--------------

.. autofunction:: skimage.img_as_float32


.. include:: skimage.img_as_float32.examples

img_as_float64
--------------

.. autofunction:: skimage.img_as_float64


.. include:: skimage.img_as_float64.examples

img_as_int
----------

.. autofunction:: skimage.img_as_int


.. include:: skimage.img_as_int.examples

img_as_ubyte
------------

.. autofunction:: skimage.img_as_ubyte


.. include:: skimage.img_as_ubyte.examples

img_as_uint
-----------

.. autofunction:: skimage.img_as_uint


.. include:: skimage.img_as_uint.examples

lookfor
-------

.. autofunction:: skimage.lookfor


.. include:: skimage.lookfor.examples

